@@ -1,5 +1,4 @@
-splitme <-
-function(x)
+splitme <- function(x)
 {
   return(strsplit(x, "")[[1L]])
 }
